@@ -1,30 +1,30 @@
-#include <Elementary.h>
 #ifdef HAVE_CONFIG_H
 # include "elementary_config.h"
 #endif
+#include <Elementary.h>
 #ifndef ELM_LIB_QUICKLAUNCH
 typedef struct _Testitem
 {
-   Elm_Genlist_Item *item;
+   Elm_Object_Item *item;
    int mode;
    int onoff;
 } Testitem;
 
 
 static Elm_Genlist_Item_Class itc1;
-static char *glf_label_get(void *data, Evas_Object *obj __UNUSED__, const char *part __UNUSED__)
+static char *glf_text_get(void *data, Evas_Object *obj __UNUSED__, const char *part __UNUSED__)
 {
    char buf[256];
-   snprintf(buf, sizeof(buf), "Item # %i", (int)(long)data);
+   snprintf(buf, sizeof(buf), "Item # %i", (int)(uintptr_t)data);
    return strdup(buf);
 }
 
-static Evas_Object *glf_icon_get(void *data __UNUSED__, Evas_Object *obj, const char *part __UNUSED__)
+static Evas_Object *glf_content_get(void *data __UNUSED__, Evas_Object *obj, const char *part __UNUSED__)
 {
    char buf[PATH_MAX];
    Evas_Object *ic = elm_icon_add(obj);
-   snprintf(buf, sizeof(buf), "%s/images/logo_small.png", PACKAGE_DATA_DIR);
-   elm_icon_file_set(ic, buf, NULL);
+   snprintf(buf, sizeof(buf), "%s/images/logo_small.png", elm_app_data_dir_get());
+   elm_image_file_set(ic, buf, NULL);
    evas_object_size_hint_aspect_set(ic, EVAS_ASPECT_CONTROL_VERTICAL, 1, 1);
    return ic;
 }
@@ -47,7 +47,7 @@ anim(void *data)
 {
    Evas_Object *gl = data;
    Evas_Coord x, y;
-   
+
    y = 0;
    x = (sin(ecore_loop_time_get()) * 500);
    evas_object_move(gl, x, y);
@@ -58,25 +58,19 @@ static void
 _del(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    Ecore_Animator *ani = data;
-   
+
    ecore_animator_del(ani);
 }
 
 void
 test_floating(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
-   Evas_Object *win, *bg, *gl;
+   Evas_Object *win, *gl;
    int i;
    Ecore_Animator *ani;
 
-   win = elm_win_add(NULL, "floating", ELM_WIN_BASIC);
-   elm_win_title_set(win, "Floaating");
-   elm_win_autodel_set(win, 1);
-
-   bg = elm_bg_add(win);
-   elm_win_resize_object_add(win, bg);
-   evas_object_size_hint_weight_set(bg, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
-   evas_object_show(bg);
+   win = elm_win_util_standard_add("floating", "Floating");
+   elm_win_autodel_set(win, EINA_TRUE);
 
    gl = elm_genlist_add(win);
    evas_object_size_hint_weight_set(gl, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
@@ -86,23 +80,23 @@ test_floating(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_in
    evas_object_show(gl);
 
    itc1.item_style     = "default";
-   itc1.func.label_get = glf_label_get;
-   itc1.func.icon_get  = glf_icon_get;
+   itc1.func.text_get = glf_text_get;
+   itc1.func.content_get  = glf_content_get;
    itc1.func.state_get = glf_state_get;
    itc1.func.del       = glf_del;
 
    for (i = 0; i < 20; i++)
      {
         elm_genlist_item_append(gl, &itc1,
-                                (void *)(long)i/* item data */,
+                                (void *)(uintptr_t)i/* item data */,
                                 NULL/* parent */,
                                 ELM_GENLIST_ITEM_NONE,
                                 gl_sel/* func */,
-                                (void *)(long)(i * 10)/* func data */);
+                                (void *)(uintptr_t)(i * 10)/* func data */);
      }
    evas_object_resize(win, 480, 800);
    evas_object_show(win);
-   
+
    ani = ecore_animator_add(anim, gl);
    evas_object_event_callback_add(win, EVAS_CALLBACK_DEL, _del, ani);
 }
