@@ -1,5 +1,5 @@
+#include "elementary_config.h"
 #include <Elementary.h>
-#include <elementary_config.h>
 #ifndef ELM_LIB_QUICKLAUNCH
 static void
 my_hover_bt(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
@@ -9,6 +9,14 @@ my_hover_bt(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__
    evas_object_show(hv);
 }
 
+static void
+_top_bt_clicked(void *data, Evas_Object *obj __UNUSED__,
+                void *event_info __UNUSED__)
+{
+   Evas_Object *hv = (Evas_Object *)data;
+   elm_hover_dismiss(hv);
+}
+
 void
 test_hover(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
@@ -17,7 +25,7 @@ test_hover(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
 
    win = elm_win_add(NULL, "hover", ELM_WIN_BASIC);
    elm_win_title_set(win, "Hover");
-   elm_win_autodel_set(win, 1);
+   elm_win_autodel_set(win, EINA_TRUE);
 
    bg = elm_bg_add(win);
    elm_win_resize_object_add(win, bg);
@@ -32,7 +40,7 @@ test_hover(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
    hv = elm_hover_add(win);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Button");
+   elm_object_text_set(bt, "Button");
    evas_object_smart_callback_add(bt, "clicked", my_hover_bt, hv);
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
@@ -40,53 +48,54 @@ test_hover(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
    elm_hover_target_set(hv, bt);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Popup");
-   elm_hover_content_set(hv, "middle", bt);
+   elm_object_text_set(bt, "Popup");
+   elm_object_part_content_set(hv, "middle", bt);
    evas_object_show(bt);
 
    bx = elm_box_add(win);
 
    ic = elm_icon_add(win);
-   snprintf(buf, sizeof(buf), "%s/images/logo_small.png", PACKAGE_DATA_DIR);
-   elm_icon_file_set(ic, buf, NULL);
-   elm_icon_scale_set(ic, 0, 0);
+   snprintf(buf, sizeof(buf), "%s/images/logo_small.png", elm_app_data_dir_get());
+   elm_image_file_set(ic, buf, NULL);
+   elm_image_resizable_set(ic, 0, 0);
    elm_box_pack_end(bx, ic);
    evas_object_show(ic);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Top 1");
+   elm_object_text_set(bt, "Top 1");
+   evas_object_smart_callback_add(bt, "clicked", _top_bt_clicked, hv);
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Top 2");
+   elm_object_text_set(bt, "Top 2");
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Top 3");
+   elm_object_text_set(bt, "Top 3");
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
 
    evas_object_show(bx);
-   elm_hover_content_set(hv, "top", bx);
+   elm_object_part_content_set(hv, "top", bx);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Bottom");
-   elm_hover_content_set(hv, "bottom", bt);
+   elm_object_text_set(bt, "Bottom");
+   elm_object_part_content_set(hv, "bottom", bt);
    evas_object_show(bt);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Left");
-   elm_hover_content_set(hv, "left", bt);
+   elm_object_text_set(bt, "Left");
+   elm_object_part_content_set(hv, "left", bt);
    evas_object_show(bt);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Right");
-   elm_hover_content_set(hv, "right", bt);
+   elm_object_text_set(bt, "Right");
+   elm_object_part_content_set(hv, "right", bt);
    evas_object_show(bt);
 
    evas_object_size_hint_min_set(bg, 160, 160);
    evas_object_size_hint_max_set(bg, 640, 640);
-   evas_object_resize(win, 320, 320);
+   evas_object_resize(win, 440, 440);
    evas_object_show(win);
 }
 
@@ -98,7 +107,7 @@ test_hover2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
 
    win = elm_win_add(NULL, "hover2", ELM_WIN_BASIC);
    elm_win_title_set(win, "Hover 2");
-   elm_win_autodel_set(win, 1);
+   elm_win_autodel_set(win, EINA_TRUE);
 
    bg = elm_bg_add(win);
    elm_win_resize_object_add(win, bg);
@@ -114,7 +123,7 @@ test_hover2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
    elm_object_style_set(hv, "popout");
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Button");
+   elm_object_text_set(bt, "Button");
    evas_object_smart_callback_add(bt, "clicked", my_hover_bt, hv);
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
@@ -122,51 +131,51 @@ test_hover2(void *data __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info
    elm_hover_target_set(hv, bt);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Popup");
-   elm_hover_content_set(hv, "middle", bt);
+   elm_object_text_set(bt, "Popup");
+   elm_object_part_content_set(hv, "middle", bt);
    evas_object_show(bt);
 
    bx = elm_box_add(win);
 
    ic = elm_icon_add(win);
-   snprintf(buf, sizeof(buf), "%s/images/logo_small.png", PACKAGE_DATA_DIR);
-   elm_icon_file_set(ic, buf, NULL);
-   elm_icon_scale_set(ic, 0, 0);
+   snprintf(buf, sizeof(buf), "%s/images/logo_small.png", elm_app_data_dir_get());
+   elm_image_file_set(ic, buf, NULL);
+   elm_image_resizable_set(ic, 0, 0);
    elm_box_pack_end(bx, ic);
    evas_object_show(ic);
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Top 1");
+   elm_object_text_set(bt, "Top 1");
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Top 2");
+   elm_object_text_set(bt, "Top 2");
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Top 3");
+   elm_object_text_set(bt, "Top 3");
    elm_box_pack_end(bx, bt);
    evas_object_show(bt);
    evas_object_show(bx);
-   elm_hover_content_set(hv, "top", bx);
+   elm_object_part_content_set(hv, "top", bx);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Bot");
-   elm_hover_content_set(hv, "bottom", bt);
+   elm_object_text_set(bt, "Bot");
+   elm_object_part_content_set(hv, "bottom", bt);
    evas_object_show(bt);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Left");
-   elm_hover_content_set(hv, "left", bt);
+   elm_object_text_set(bt, "Left");
+   elm_object_part_content_set(hv, "left", bt);
    evas_object_show(bt);
 
    bt = elm_button_add(win);
-   elm_button_label_set(bt, "Right");
-   elm_hover_content_set(hv, "right", bt);
+   elm_object_text_set(bt, "Right");
+   elm_object_part_content_set(hv, "right", bt);
    evas_object_show(bt);
 
    evas_object_size_hint_min_set(bg, 160, 160);
    evas_object_size_hint_max_set(bg, 640, 640);
-   evas_object_resize(win, 320, 320);
+   evas_object_resize(win, 440, 440);
    evas_object_show(win);
 }
 #endif
