@@ -18,7 +18,7 @@ typedef struct _Elm_Params_List
 
 #define CHOICE_GET(CHOICES, STR)                \
   unsigned int i;                               \
-  for (i = 0; i < sizeof(CHOICES); i++)         \
+  for (i = 0; i < (sizeof(CHOICES)/sizeof(CHOICES[0])); i++)         \
     if (strcmp(STR, CHOICES[i]) == 0)           \
       return i
 
@@ -66,20 +66,20 @@ external_list_state_set(void *data __UNUSED__, Evas_Object *obj, const void *fro
      {
         policy_h = _scroller_policy_choices_setting_get(p->policy_h);
         policy_v = _scroller_policy_choices_setting_get(p->policy_v);
-        elm_list_scroller_policy_set(obj, policy_h, policy_v);
+        elm_scroller_policy_set(obj, policy_h, policy_v);
      }
    else if ((p->policy_h) || (p->policy_v))
      {
-        elm_list_scroller_policy_get(obj, &policy_h, &policy_v);
+        elm_scroller_policy_get(obj, &policy_h, &policy_v);
         if (p->policy_h)
           {
              policy_h = _scroller_policy_choices_setting_get(p->policy_h);
-             elm_list_scroller_policy_set(obj, policy_h, policy_v);
+             elm_scroller_policy_set(obj, policy_h, policy_v);
           }
         else
           {
              policy_v = _scroller_policy_choices_setting_get(p->policy_v);
-             elm_list_scroller_policy_set(obj, policy_h, policy_v);
+             elm_scroller_policy_set(obj, policy_h, policy_v);
           }
      }
 
@@ -88,7 +88,12 @@ external_list_state_set(void *data __UNUSED__, Evas_Object *obj, const void *fro
    if (p->multi_exists)
      elm_list_multi_select_set(obj, p->multi);
    if (p->always_select_exists)
-     elm_list_always_select_mode_set(obj, p->always_select);
+     {
+        if (p->always_select)
+          elm_list_select_mode_set (obj, ELM_OBJECT_SELECT_MODE_ALWAYS);
+        else
+          elm_list_select_mode_set (obj, ELM_OBJECT_SELECT_MODE_DEFAULT);
+     }
 }
 
 static Eina_Bool
@@ -109,10 +114,10 @@ external_list_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Exte
         if (param->type == EDJE_EXTERNAL_PARAM_TYPE_CHOICE)
           {
              Elm_Scroller_Policy h, v;
-             elm_list_scroller_policy_get(obj, &h, &v);
+             elm_scroller_policy_get(obj, &h, &v);
              h = _scroller_policy_choices_setting_get(param->s);
              if (h == ELM_SCROLLER_POLICY_LAST) return EINA_FALSE;
-             elm_list_scroller_policy_set(obj, h, v);
+             elm_scroller_policy_set(obj, h, v);
              return EINA_TRUE;
           }
      }
@@ -121,10 +126,10 @@ external_list_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Exte
         if (param->type == EDJE_EXTERNAL_PARAM_TYPE_CHOICE)
           {
              Elm_Scroller_Policy h, v;
-             elm_list_scroller_policy_get(obj, &h, &v);
+             elm_scroller_policy_get(obj, &h, &v);
              v = _scroller_policy_choices_setting_get(param->s);
              if (v == ELM_SCROLLER_POLICY_LAST) return EINA_FALSE;
-             elm_list_scroller_policy_set(obj, h, v);
+             elm_scroller_policy_set(obj, h, v);
              return EINA_TRUE;
           }
      }
@@ -148,7 +153,10 @@ external_list_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Exte
      {
         if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
           {
-             elm_list_always_select_mode_set(obj, param->i);
+             if (param->i)
+               elm_list_select_mode_set (obj, ELM_OBJECT_SELECT_MODE_ALWAYS);
+             else
+               elm_list_select_mode_set (obj, ELM_OBJECT_SELECT_MODE_DEFAULT);
              return EINA_TRUE;
           }
      }
@@ -182,7 +190,11 @@ external_list_param_get(void *data __UNUSED__, const Evas_Object *obj, Edje_Exte
      {
         if (param->type == EDJE_EXTERNAL_PARAM_TYPE_BOOL)
           {
-             param->i = elm_list_always_select_mode_get(obj);
+             if (elm_list_select_mode_get (obj) ==
+                 ELM_OBJECT_SELECT_MODE_ALWAYS)
+               param->i = EINA_TRUE;
+             else
+               param->i = EINA_FALSE;
              return EINA_TRUE;
           }
      }
@@ -191,7 +203,7 @@ external_list_param_get(void *data __UNUSED__, const Evas_Object *obj, Edje_Exte
         if (param->type == EDJE_EXTERNAL_PARAM_TYPE_CHOICE)
           {
              Elm_Scroller_Policy h, v;
-             elm_list_scroller_policy_get(obj, &h, &v);
+             elm_scroller_policy_get(obj, &h, &v);
 
              param->s = scroller_policy_choices[h];
              return EINA_TRUE;
@@ -202,7 +214,7 @@ external_list_param_get(void *data __UNUSED__, const Evas_Object *obj, Edje_Exte
         if (param->type == EDJE_EXTERNAL_PARAM_TYPE_CHOICE)
           {
              Elm_Scroller_Policy h, v;
-             elm_list_scroller_policy_get(obj, &h, &v);
+             elm_scroller_policy_get(obj, &h, &v);
 
              param->s = scroller_policy_choices[v];
              return EINA_TRUE;
