@@ -28,9 +28,9 @@ external_slider_state_set(void *data __UNUSED__, Evas_Object *obj, const void *f
    else return;
 
    if (p->label)
-     elm_slider_label_set(obj, p->label);
+     elm_object_text_set(obj, p->label);
    if (p->icon)
-     elm_slider_icon_set(obj, p->icon);
+     elm_object_part_content_set(obj, "icon", p->icon);
    if (p->span_exists)
      elm_slider_span_size_set(obj, p->span);
    if ((p->min_exists) && (p->max_exists))
@@ -63,7 +63,7 @@ external_slider_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Ex
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     elm_slider_label_set(obj, param->s);
+	     elm_object_text_set(obj, param->s);
 	     return EINA_TRUE;
 	  }
      }
@@ -73,7 +73,7 @@ external_slider_param_set(void *data __UNUSED__, Evas_Object *obj, const Edje_Ex
 	  {
 	     Evas_Object *icon = external_common_param_icon_get(obj, param);
 	     if ((strcmp(param->s, "")) && (!icon)) return EINA_FALSE;
-	     elm_slider_icon_set(obj, icon);
+	     elm_object_part_content_set(obj, "icon", icon);
 	     return EINA_TRUE;
 	  }
      }
@@ -159,7 +159,7 @@ external_slider_param_get(void *data __UNUSED__, const Evas_Object *obj, Edje_Ex
      {
 	if (param->type == EDJE_EXTERNAL_PARAM_TYPE_STRING)
 	  {
-	     param->s = elm_slider_label_get(obj);
+	     param->s = elm_object_text_get(obj);
 	     return EINA_TRUE;
 	  }
      }
