@@ -7,18 +7,9 @@
 #include <Ecore_X_Cursor.h>
 #endif
 
-/**
- * @defgroup Cursors Cursors
- *
- * The Cursor is an internal smart object used to customize the
- * cursor displayed over objects (or widgets).
- * It can use default X cursors (if using X), or cursors from a
- * theme.
- */
-
 #define _cursor_key "_elm_cursor"
 
-struct _Cursor_Id 
+struct _Cursor_Id
 {
    const char *name;
 #ifdef HAVE_ELEMENTARY_X
@@ -144,9 +135,17 @@ struct _Elm_Cursor
    Ecore_Evas *ee;
    Evas *evas;
 #ifdef HAVE_ELEMENTARY_X
-   Ecore_X_Cursor cursor;
-   Ecore_X_Window win;
+   struct {
+     Ecore_X_Cursor cursor;
+     Ecore_X_Window win;
+   } x;
 #endif
+#ifdef HAVE_ELEMENTARY_WAYLAND
+   struct {
+     Ecore_Wl_Window *win;
+   } wl;
+#endif
+
    Eina_Bool visible:1;
    Eina_Bool use_engine:1;
    Eina_Bool engine_only:1;
@@ -156,8 +155,13 @@ static void
 _elm_cursor_obj_del(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    Elm_Cursor *cur = data;
-
-   if (cur) cur->obj = NULL;
+   
+   if (cur)
+     {
+        evas_object_event_callback_del_full(cur->obj, EVAS_CALLBACK_DEL,
+                                            _elm_cursor_obj_del, cur);
+        cur->obj = NULL;
+     }
 }
 
 static Eina_Bool
@@ -219,7 +223,12 @@ _elm_cursor_mouse_in(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSE
    else
      {
 #ifdef HAVE_ELEMENTARY_X
-        ecore_x_window_cursor_set(cur->win, cur->cursor);
+        if (cur->x.win)
+          ecore_x_window_cursor_set(cur->x.win, cur->x.cursor);
+#endif
+#ifdef HAVE_ELEMENTARY_WAYLAND
+        if (cur->wl.win)
+          ecore_wl_window_cursor_from_name_set(cur->wl.win, cur->cursor_name);
 #endif
      }
    evas_event_thaw(cur->evas);
@@ -253,14 +262,17 @@ _elm_cursor_mouse_out(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUS
      }
 
    if ((!cur->engine_only) || (!cur->use_engine))
-     {
-        ecore_evas_object_cursor_set(cur->ee, NULL, ELM_OBJECT_LAYER_CURSOR,
-                                     cur->hot_x, cur->hot_y);
-     }
+     ecore_evas_object_cursor_set(cur->ee, NULL, ELM_OBJECT_LAYER_CURSOR,
+                                  cur->hot_x, cur->hot_y);
    else
      {
 #ifdef HAVE_ELEMENTARY_X
-        ecore_x_window_cursor_set(cur->win, ECORE_X_CURSOR_X);
+        if (cur->x.win)
+          ecore_x_window_cursor_set(cur->x.win, ECORE_X_CURSOR_X);
+#endif
+#ifdef HAVE_ELEMENTARY_WAYLAND
+        if (cur->wl.win)
+          ecore_wl_window_cursor_default_restore(cur->wl.win);
 #endif
      }
    evas_event_thaw(cur->evas);
@@ -272,6 +284,7 @@ _elm_cursor_del(void *data __UNUSED__, Evas *evas __UNUSED__, Evas_Object *obj,
    elm_object_cursor_unset(obj);
 }
 
+#ifdef HAVE_ELEMENTARY_X
 static int
 _elm_cursor_strcmp(const void *data1, const void *data2)
 {
@@ -279,6 +292,7 @@ _elm_cursor_strcmp(const void *data1, const void *data2)
    const struct _Cursor_Id *c2 = data2;
    return strcmp (c1->name, c2->name);
 }
+#endif
 
 static void
 _elm_cursor_cur_set(Elm_Cursor *cur)
@@ -303,21 +317,26 @@ _elm_cursor_cur_set(Elm_Cursor *cur)
    if (cur->use_engine)
      {
 #ifdef HAVE_ELEMENTARY_X
-        struct _Cursor_Id cur_search, *cur_id;
-
-        cur_search.name = cur->cursor_name;
-        cur_id = bsearch(&(cur->cursor_name), _cursors, _cursors_count,
-                         sizeof(struct _Cursor_Id), _elm_cursor_strcmp);
-
-        cur->win = elm_win_xwindow_get(cur->eventarea);
-        if (!cur_id)
+        cur->x.win = elm_win_xwindow_get(cur->eventarea);
+        if (cur->x.win)
           {
-             INF("X cursor couldn't be found: %s. Using default.",
-                 cur->cursor_name);
-             cur->cursor = ecore_x_cursor_shape_get(ECORE_X_CURSOR_X);
+             struct _Cursor_Id *cur_id;
+
+             cur_id = bsearch(&(cur->cursor_name), _cursors, _cursors_count,
+                              sizeof(struct _Cursor_Id), _elm_cursor_strcmp);
+
+             if (!cur_id)
+               {
+                  INF("X cursor couldn't be found: %s. Using default.",
+                      cur->cursor_name);
+                  cur->x.cursor = ecore_x_cursor_shape_get(ECORE_X_CURSOR_X);
+               }
+             else
+                cur->x.cursor = ecore_x_cursor_shape_get(cur_id->id);
           }
-        else
-           cur->cursor = ecore_x_cursor_shape_get(cur_id->id);
+#endif
+#ifdef HAVE_ELEMENTARY_WAYLAND
+        cur->wl.win = elm_win_wl_window_get(cur->eventarea);
 #endif
      }
 }
@@ -386,22 +405,6 @@ elm_object_sub_cursor_set(Evas_Object *eventarea, Evas_Object *owner, const char
                                   _elm_cursor_del, cur);
 }
 
-/**
- * Set the cursor to be shown when mouse is over the object
- *
- * Set the cursor that will be displayed when mouse is over the
- * object. The object can have only one cursor set to it, so if
- * this function is called twice for an object, the previous set
- * will be unset.
- * If using X cursors, a definition of all the valid cursor names
- * is listed on Elementary_Cursors.h. If an invalid name is set
- * the default cursor will be used.
- *
- * @param obj the object being set a cursor.
- * @param cursor the cursor name to be used.
- *
- * @ingroup Cursors
- */
 EAPI void
 elm_object_cursor_set(Evas_Object *obj, const char *cursor)
 {
@@ -409,14 +412,6 @@ elm_object_cursor_set(Evas_Object *obj, const char *cursor)
    elm_object_sub_cursor_set(obj, obj, cursor);
 }
 
-/**
- * Get the cursor to be shown when mouse is over the object
- *
- * @param obj an object with cursor already set.
- * @return the cursor name.
- *
- * @ingroup Cursors
- */
 EAPI const char *
 elm_object_cursor_get(const Evas_Object *obj)
 {
@@ -424,17 +419,6 @@ elm_object_cursor_get(const Evas_Object *obj)
    return cur->cursor_name;
 }
 
-/**
- * Unset cursor for object
- *
- * Unset cursor for object, and set the cursor to default if the mouse
- * was over this object.
- *
- * @param obj Target object
- * @see elm_object_cursor_set()
- *
- * @ingroup Cursors
- */
 EAPI void
 elm_object_cursor_unset(Evas_Object *obj)
 {
@@ -447,7 +431,12 @@ elm_object_cursor_unset(Evas_Object *obj)
      elm_widget_cursor_del(cur->owner, cur);
 
    if (cur->obj)
-     evas_object_del(cur->obj);
+     {
+        evas_object_event_callback_del_full(cur->obj, EVAS_CALLBACK_DEL,
+                                            _elm_cursor_obj_del, cur);
+        evas_object_del(cur->obj);
+        cur->obj = NULL;
+     }
 
    if (cur->visible)
      {
@@ -455,32 +444,21 @@ elm_object_cursor_unset(Evas_Object *obj)
           ecore_evas_object_cursor_set(cur->ee, NULL, ELM_OBJECT_LAYER_CURSOR,
                                        cur->hot_x, cur->hot_y);
 #ifdef HAVE_ELEMENTARY_X
-        else
-          ecore_x_window_cursor_set(cur->win, ECORE_X_CURSOR_X);
+        else if (cur->x.win)
+          ecore_x_window_cursor_set(cur->x.win, ECORE_X_CURSOR_X);
 #endif
      }
 
-   evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_IN,
-                                  _elm_cursor_mouse_in);
-   evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_OUT,
-                                  _elm_cursor_mouse_out);
-   evas_object_event_callback_del(obj, EVAS_CALLBACK_DEL, _elm_cursor_del);
-
+   evas_object_event_callback_del_full(obj, EVAS_CALLBACK_MOUSE_IN,
+                                  _elm_cursor_mouse_in, cur);
+   evas_object_event_callback_del_full(obj, EVAS_CALLBACK_MOUSE_OUT,
+                                  _elm_cursor_mouse_out, cur);
+   evas_object_event_callback_del_full(obj, EVAS_CALLBACK_DEL,
+                                       _elm_cursor_del, cur);
    evas_object_data_del(obj, _cursor_key);
    free(cur);
 }
 
-/**
- * Sets a different style for this object cursor.
- *
- * @note before you set a style you should define a cursor with
- *       elm_object_cursor_set()
- *
- * @param obj an object with cursor already set.
- * @param style the theme style to use (default, transparent, ...)
- *
- * @ingroup Cursors
- */
 EAPI void
 elm_object_cursor_style_set(Evas_Object *obj, const char *style)
 {
@@ -508,15 +486,6 @@ elm_object_cursor_style_set(Evas_Object *obj, const char *style)
      }
 }
 
-/**
- * Get the style for this object cursor.
- *
- * @param obj an object with cursor already set.
- * @return style the theme style in use, defaults to "default". If the
- *         object does not have a cursor set, then NULL is returned.
- *
- * @ingroup Cursors
- */
 EAPI const char *
 elm_object_cursor_style_get(const Evas_Object *obj)
 {
@@ -539,25 +508,11 @@ elm_cursor_theme(Elm_Cursor *cur)
      _elm_cursor_set_hot_spots(cur);
 }
 
-/**
- * Set if the cursor set should be searched on the theme or should use
- * the provided by the engine, only.
- *
- * @note before you set if should look on theme you should define a cursor
- * with elm_object_cursor_set(). By default it will only look for cursors
- * provided by the engine.
- *
- * @param obj an object with cursor already set.
- * @param engine_only boolean to define it cursors should be looked only
- * between the provided by the engine or searched on widget's theme as well.
- *
- * @ingroup Cursors
- */
 EAPI void
-elm_object_cursor_engine_only_set(Evas_Object *obj, Eina_Bool engine_only)
+elm_object_cursor_theme_search_enabled_set(Evas_Object *obj, Eina_Bool theme_search)
 {
    ELM_CURSOR_GET_OR_RETURN(cur, obj);
-   cur->engine_only = engine_only;
+   cur->engine_only = theme_search;
    if (cur->obj)
      {
         evas_object_del(cur->obj);
@@ -566,52 +521,10 @@ elm_object_cursor_engine_only_set(Evas_Object *obj, Eina_Bool engine_only)
    _elm_cursor_cur_set(cur);
 }
 
-/**
- * Get the cursor engine only usage for this object cursor.
- *
- * @param obj an object with cursor already set.
- * @return engine_only boolean to define it cursors should be looked only
- * between the provided by the engine or searched on widget's theme as well. If
- *         the object does not have a cursor set, then EINA_FALSE is returned.
- *
- * @ingroup Cursors
- */
+
 EAPI Eina_Bool
-elm_object_cursor_engine_only_get(const Evas_Object *obj)
+elm_object_cursor_theme_search_enabled_get(const Evas_Object *obj)
 {
    ELM_CURSOR_GET_OR_RETURN(cur, obj, EINA_FALSE);
    return cur->engine_only;
 }
-
-/**
- * Get the configured cursor engine only usage
- *
- * This gets the globally configured exclusive usage of engine cursors.
- *
- * @return 1 if only engine cursors should be used
- * @ingroup Cursors
- */
-EAPI int
-elm_cursor_engine_only_get(void)
-{
-   return _elm_config->cursor_engine_only;
-}
-
-/**
- * Set the configured cursor engine only usage
- *
- * This sets the globally configured exclusive usage of engine cursors.
- * It won't affect cursors set before changing this value.
- *
- * @param engine_only If 1 only engine cursors will be enabled, if 0 will
- * look for them on theme before.
- * @return EINA_TRUE if value is valid and setted (0 or 1)
- * @ingroup Cursors
- */
-EAPI Eina_Bool
-elm_cursor_engine_only_set(int engine_only)
-{
-   if ((engine_only < 0) || (engine_only > 1)) return EINA_FALSE;
-   _elm_config->cursor_engine_only = engine_only;
-   return EINA_TRUE;
-}
