@@ -1,13 +1,13 @@
 #include <Elementary.h>
 #include "elm_priv.h"
 
-/**
- * @defgroup Tooltips Tooltips
- *
- * The Tooltip is an (internal, for now) smart object used to show a
- * content in a frame on mouse hover of objects(or widgets), with
- * tips/information about them.
- */
+#ifdef ISCOMFITOR
+# define STR(X) #X
+# define STUPID(X) STR(X)
+# define TTDBG(x...) fprintf(stderr, STUPID(__LINE__)": " x)
+#else
+# define TTDBG(X...)
+#endif
 
 static const char _tooltip_key[] = "_elm_tooltip";
 
@@ -35,21 +35,26 @@ struct _Elm_Tooltip
    Evas_Smart_Cb            del_cb;
    const void              *data;
    const char              *style;
-   Evas                    *evas;
+   Evas                    *evas, *tt_evas;
    Evas_Object             *eventarea, *owner;
    Evas_Object             *tooltip, *content;
+   Evas_Object             *tt_win;
    Ecore_Timer             *show_timer;
    Ecore_Timer             *hide_timer;
    Ecore_Job               *reconfigure_job;
-   struct {
-      Evas_Coord            x, y, bx, by;
-   } pad;
-   struct {
-      double                x, y;
-   } rel_pos;
+   Evas_Coord               mouse_x, mouse_y;
+   struct
+     {
+        Evas_Coord            x, y, bx, by;
+     } pad;
+   struct
+     {
+        double                x, y;
+     } rel_pos;
    double                   hide_timeout; /* from theme */
    Eina_Bool                visible_lock:1;
    Eina_Bool                changed_style:1;
+   Eina_Bool                free_size : 1;
 };
 
 static void _elm_tooltip_reconfigure(Elm_Tooltip *tt);
@@ -61,11 +66,11 @@ static void _elm_tooltip_show_timer_stop(Elm_Tooltip *tt);
 static void _elm_tooltip_hide(Elm_Tooltip *tt);
 static void _elm_tooltip_data_clean(Elm_Tooltip *tt);
 
-
 static void
 _elm_tooltip_content_changed_hints_cb(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    _elm_tooltip_reconfigure_job_start(data);
+   TTDBG("HINTS CHANGED\n");
 }
 
 static void
@@ -74,7 +79,7 @@ _elm_tooltip_content_del_cb(void *data, Evas *e __UNUSED__, Evas_Object *obj __U
    Elm_Tooltip *tt = data;
    tt->content = NULL;
    tt->visible_lock = EINA_FALSE;
-   _elm_tooltip_hide(tt);
+   if (tt->tooltip) _elm_tooltip_hide(tt);
 }
 
 static void
@@ -82,6 +87,7 @@ _elm_tooltip_obj_move_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj __UNU
 {
    Elm_Tooltip *tt = data;
    _elm_tooltip_reconfigure_job_start(tt);
+   TTDBG("TT MOVED\n");
 }
 
 static void
@@ -89,12 +95,24 @@ _elm_tooltip_obj_resize_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj __U
 {
    Elm_Tooltip *tt = data;
    _elm_tooltip_reconfigure_job_start(tt);
+   TTDBG("TT RESIZE\n");
 }
 
 static void
-_elm_tooltip_obj_mouse_move_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info  __UNUSED__)
+_elm_tooltip_obj_mouse_move_cb(Elm_Tooltip *tt, Evas *e  __UNUSED__, Evas_Object *obj __UNUSED__, Evas_Event_Mouse_Move *ev)
 {
-   Elm_Tooltip *tt = data;
+   if (tt->mouse_x || tt->mouse_y)
+     {
+        if ((abs(ev->cur.output.x - tt->mouse_x) < 3) &&
+            (abs(ev->cur.output.y - tt->mouse_y) < 3))
+          {
+             TTDBG("MOUSE MOVE REJECTED!\n");
+             return;
+          }
+     }
+   tt->mouse_x = ev->cur.output.x;
+   tt->mouse_y = ev->cur.output.y;
+   TTDBG("MOUSE MOVED\n");
    _elm_tooltip_reconfigure_job_start(tt);
 }
 
@@ -104,24 +122,37 @@ _elm_tooltip_show(Elm_Tooltip *tt)
    _elm_tooltip_show_timer_stop(tt);
    _elm_tooltip_hide_anim_stop(tt);
 
+   TTDBG("TT SHOW\n");
    if (tt->tooltip)
      {
         _elm_tooltip_reconfigure_job_start(tt);
+        TTDBG("RECURSIVE JOB\n");
         return;
      }
-   tt->tooltip = edje_object_add(tt->evas);
+   if (tt->free_size)
+     {
+        tt->tt_win = elm_win_add(NULL, "tooltip", ELM_WIN_TOOLTIP);
+        elm_win_override_set(tt->tt_win, EINA_TRUE);
+        tt->tt_evas = evas_object_evas_get(tt->tt_win);
+        tt->tooltip = edje_object_add(tt->tt_evas);
+        evas_object_size_hint_weight_set(tt->tooltip, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+        evas_object_size_hint_align_set(tt->tooltip, EVAS_HINT_FILL, EVAS_HINT_FILL);
+        elm_win_resize_object_add(tt->tt_win, tt->tooltip);
+     }
+   else
+      tt->tooltip = edje_object_add(tt->evas);
    if (!tt->tooltip) return;
 
-   evas_object_layer_set(tt->tooltip, ELM_OBJECT_LAYER_TOOLTIP);
+   if (tt->free_size)
+     evas_object_layer_set(tt->tooltip, ELM_OBJECT_LAYER_TOOLTIP);
 
    evas_object_event_callback_add
      (tt->eventarea, EVAS_CALLBACK_MOVE, _elm_tooltip_obj_move_cb, tt);
    evas_object_event_callback_add
      (tt->eventarea, EVAS_CALLBACK_RESIZE, _elm_tooltip_obj_resize_cb, tt);
    evas_object_event_callback_add
-     (tt->eventarea, EVAS_CALLBACK_MOUSE_MOVE, _elm_tooltip_obj_mouse_move_cb, tt);
+     (tt->eventarea, EVAS_CALLBACK_MOUSE_MOVE, (Evas_Object_Event_Cb)_elm_tooltip_obj_mouse_move_cb, tt);
 
-   evas_object_pass_events_set(tt->tooltip, EINA_TRUE);
    tt->changed_style = EINA_TRUE;
    _elm_tooltip_reconfigure_job_start(tt);
 }
@@ -131,12 +162,14 @@ _elm_tooltip_content_del(Elm_Tooltip *tt)
 {
    if (!tt->content) return;
 
+   TTDBG("CONTENT DEL\n");
    evas_object_event_callback_del_full
      (tt->content, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
       _elm_tooltip_content_changed_hints_cb, tt);
    evas_object_event_callback_del_full
      (tt->content, EVAS_CALLBACK_DEL,
       _elm_tooltip_content_del_cb, tt);
+   evas_object_hide(tt->content);
    evas_object_del(tt->content);
    tt->content = NULL;
 }
@@ -145,6 +178,8 @@ _elm_tooltip_content_del(Elm_Tooltip *tt)
 static void
 _elm_tooltip_hide(Elm_Tooltip *tt)
 {
+   Evas_Object *del;
+   TTDBG("TT HIDE\n");
    _elm_tooltip_show_timer_stop(tt);
    _elm_tooltip_hide_anim_stop(tt);
    _elm_tooltip_reconfigure_job_stop(tt);
@@ -159,10 +194,14 @@ _elm_tooltip_hide(Elm_Tooltip *tt)
    evas_object_event_callback_del_full
      (tt->eventarea, EVAS_CALLBACK_RESIZE, _elm_tooltip_obj_resize_cb, tt);
    evas_object_event_callback_del_full
-     (tt->eventarea, EVAS_CALLBACK_MOUSE_MOVE, _elm_tooltip_obj_mouse_move_cb, tt);
+     (tt->eventarea, EVAS_CALLBACK_MOUSE_MOVE, (Evas_Object_Event_Cb)_elm_tooltip_obj_mouse_move_cb, tt);
 
-   evas_object_del(tt->tooltip);
+   del = tt->tt_win ?: tt->tooltip;
+
+   tt->tt_win = NULL;
+   tt->tt_evas = NULL;
    tt->tooltip = NULL;
+   evas_object_del(del);
 }
 
 static void
@@ -185,8 +224,7 @@ static void
 _elm_tooltip_reconfigure_job_start(Elm_Tooltip *tt)
 {
    if (tt->reconfigure_job) ecore_job_del(tt->reconfigure_job);
-   tt->reconfigure_job = ecore_job_add
-     (_elm_tooltip_reconfigure_job, tt);
+   tt->reconfigure_job = ecore_job_add(_elm_tooltip_reconfigure_job, tt);
 }
 
 static Eina_Bool
@@ -201,10 +239,14 @@ _elm_tooltip_hide_anim_cb(void *data)
 static void
 _elm_tooltip_hide_anim_start(Elm_Tooltip *tt)
 {
+   double extra = 0;
    if (tt->hide_timer) return;
+   TTDBG("HIDE START\n");
+   /* hide slightly faster when in window mode to look less stupid */
+   if ((tt->hide_timeout > 0) && tt->tt_win) extra = 0.1;
    edje_object_signal_emit(tt->tooltip, "elm,action,hide", "elm");
    tt->hide_timer = ecore_timer_add
-     (tt->hide_timeout, _elm_tooltip_hide_anim_cb, tt);
+     (tt->hide_timeout - extra, _elm_tooltip_hide_anim_cb, tt);
 }
 
 static void
@@ -220,7 +262,7 @@ _elm_tooltip_hide_anim_stop(Elm_Tooltip *tt)
 static void
 _elm_tooltip_reconfigure(Elm_Tooltip *tt)
 {
-   Evas_Coord ox, oy, ow, oh, px, py, tx, ty, tw, th, cw, ch;
+   Evas_Coord ox, oy, ow, oh, px, py, tx, ty, tw, th, cw = 0, ch = 0;
    Evas_Coord eminw, eminh, ominw, ominh;
    double rel_x, rel_y;
    Eina_Bool inside_eventarea;
@@ -233,11 +275,13 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
      {
         const char *style = tt->style ? tt->style : "default";
         const char *str;
-        if (!_elm_theme_object_set
-            (tt->owner, tt->tooltip, "tooltip", "base", style))
+        if (!_elm_theme_object_set(tt->tt_win ? NULL : tt->owner, tt->tooltip, "tooltip", "base", style))
           {
              ERR("Could not apply the theme to the tooltip! style=%s", style);
-             evas_object_del(tt->tooltip);
+             if (tt->tt_win) evas_object_del(tt->tt_win);
+             else evas_object_del(tt->tooltip);
+             tt->tt_win = NULL;
+             tt->tt_evas = NULL;
              tt->tooltip = NULL;
              return;
           }
@@ -251,6 +295,29 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
         tt->pad.by = 0;
         tt->hide_timeout = 0.0;
 
+        str = edje_object_data_get(tt->tooltip, "transparent");
+        if (tt->tt_win)
+          {  /* FIXME: hardcoded here is bad */
+             if (str && (!strcmp(str, "enabled")))
+               {
+                  evas_object_hide(tt->tt_win);
+                  elm_win_alpha_set(tt->tt_win, EINA_TRUE);
+#ifdef HAVE_ELEMENTARY_X
+                  ecore_x_window_shape_input_rectangle_set(elm_win_xwindow_get(tt->tt_win), 0, 0, 0, 0);
+#endif
+                  evas_object_show(tt->tt_win);
+               }
+             else
+               {
+                  evas_object_hide(tt->tt_win);
+                  elm_win_alpha_set(tt->tt_win, EINA_FALSE);
+#ifdef HAVE_ELEMENTARY_X
+                  ecore_x_window_shape_input_rectangle_set(elm_win_xwindow_get(tt->tt_win), 0, 0, 0, 0);
+#endif
+                  evas_object_show(tt->tt_win);
+               }
+          }
+
         str = edje_object_data_get(tt->tooltip, "pad_x");
         if (str) tt->pad.x = atoi(str);
         str = edje_object_data_get(tt->tooltip, "pad_y");
@@ -264,90 +331,172 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
         str = edje_object_data_get(tt->tooltip, "hide_timeout");
         if (str)
           {
-             tt->hide_timeout = atof(str);
+             tt->hide_timeout = _elm_atof(str);
              if (tt->hide_timeout < 0.0) tt->hide_timeout = 0.0;
           }
 
         evas_object_pass_events_set(tt->tooltip, EINA_TRUE);
         tt->changed_style = EINA_FALSE;
         if (tt->tooltip)
-          edje_object_part_swallow
-            (tt->tooltip, "elm.swallow.content", tt->content);
+          edje_object_part_swallow(tt->tooltip, "elm.swallow.content",
+                                   tt->content);
 
         edje_object_signal_emit(tt->tooltip, "elm,action,show", "elm");
      }
 
    if (!tt->content)
      {
-        tt->content = tt->func((void *)tt->data, tt->owner);
+        tt->content = tt->func((void *)tt->data, tt->owner, tt->tt_win ? : tt->owner);
         if (!tt->content)
           {
              WRN("could not create tooltip content!");
-             evas_object_del(tt->tooltip);
+             if (tt->tt_win) evas_object_del(tt->tt_win);
+             else evas_object_del(tt->tooltip);
+
+             tt->tt_win = NULL;
+             tt->tt_evas = NULL;
              tt->tooltip = NULL;
              return;
           }
+        evas_object_show(tt->content);
         evas_object_layer_set(tt->content, ELM_OBJECT_LAYER_TOOLTIP);
         evas_object_pass_events_set(tt->content, EINA_TRUE);
         edje_object_part_swallow
           (tt->tooltip, "elm.swallow.content", tt->content);
-        evas_object_event_callback_add
-          (tt->content, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
+        evas_object_event_callback_add(tt->content, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
            _elm_tooltip_content_changed_hints_cb, tt);
-        evas_object_event_callback_add
-          (tt->content, EVAS_CALLBACK_DEL,
+        evas_object_event_callback_add(tt->content, EVAS_CALLBACK_DEL,
            _elm_tooltip_content_del_cb, tt);
 
      }
-
+   TTDBG("*******RECALC\n");
    evas_object_size_hint_min_get(tt->content, &ominw, &ominh);
    edje_object_size_min_get(tt->tooltip, &eminw, &eminh);
 
-   if (ominw < eminw) ominw = eminw;
-   if (ominh < eminh) ominh = eminh;
+   if (eminw && (ominw < eminw)) ominw = eminw;
+   if (eminw && (ominh < eminh)) ominh = eminh;
 
    if (ominw < 1) ominw = 10; /* at least it is noticeable */
    if (ominh < 1) ominh = 10; /* at least it is noticeable */
 
-   edje_object_size_min_restricted_calc
-     (tt->tooltip, &tw, &th, ominw, ominh);
+   edje_object_size_min_restricted_calc(tt->tooltip, &tw, &th, ominw, ominh);
+   TTDBG("TTSIZE:  tw=%d,th=%d,ominw=%d,ominh=%d\n", tw, th, ominw, ominh);
 
-   evas_output_size_get(tt->evas, &cw, &ch);
-   evas_pointer_canvas_xy_get(tt->evas, &px, &py);
+   if (tt->tt_win)
+     elm_win_screen_size_get(elm_object_top_widget_get(tt->owner), NULL, NULL, &cw, &ch);
+   if (!cw)
+     evas_output_size_get(tt->tt_evas ?: tt->evas, &cw, &ch);
+   TTDBG("SCREEN:  cw=%d,ch=%d\n", cw, ch);
 
    evas_object_geometry_get(tt->eventarea, &ox, &oy, &ow, &oh);
+   TTDBG("EVENTAREA:  ox=%d,oy=%d,ow=%d,oh=%d\n", ox, oy, ow, oh);
 
+   if (tt->tt_win)
+     {
+        int x, y;
+        Evas_Object *win = elm_object_top_widget_get(tt->owner);
+#ifdef HAVE_ELEMENTARY_X
+        Ecore_X_Window xwin = elm_win_xwindow_get(win);
+        ecore_x_pointer_xy_get(xwin, &px, &py);
+#endif
+        elm_win_screen_position_get(win, &x, &y);
+        ox += x;
+        if (px) px += x;
+        oy += y;
+        if (py) py += y;
+     }
+   else
+     evas_pointer_canvas_xy_get(tt->evas, &px, &py);
+   TTDBG("POINTER:  px=%d,py=%d\n", px, py);
    inside_eventarea = ((px >= ox) && (py >= oy) &&
                        (px <= ox + ow) && (py <= oy + oh));
    if (inside_eventarea)
      {
-        tx = px;
-        ty = py;
-
-        if (tx + tw + tt->pad.x < cw) tx += tt->pad.x;
-        if (ty + th + tt->pad.y < ch) ty += tt->pad.y;
+        /* try to position bottom right corner at pointer */
+        tx = px - tw;
+        ty = py - th;
+        TTDBG("INIT (EVENTAREA)\n");
      }
    else
      {
+        /* try centered on middle of eventarea */
         tx = ox + (ow / 2) - (tw / 2);
-        if (ch < (th + oy + oh)) ty = oy - th;
-        else ty = oy + oh;
+        if (0 > (th - oy - oh)) ty = oy + th;
+        else ty = oy - oh;
+        TTDBG("INIT (INTERPRETED)\n");
      }
+   TTDBG("ADJUST (POINTER):  tx=%d,ty=%d\n", tx, ty);
+   if ((tx < 0) || (tx + tw > cw))
+     {
+        /* if we're offscreen, try to flip over the Y axis */
+        if ((tx < 0) && (abs((tx + 2 * tw) - cw) < abs(tx)))
+          tx += tw;
+        else if (tx + tw > cw)
+          {
+             int test_x = tx - tw;
 
+             if ((test_x >= 0) || (tx + tw - cw > abs(test_x)))
+               tx -= tw;
+          }
+     }
+   else if ((tx > px) && (px > tw))
+     {
+        if (tx + tw < cw)
+          tx += tw;
+     }
+   if ((ty < 0) || (ty + th > ch))
+     {
+        /* if we're offscreen, try to flip over the X axis */
+        if ((ty < 0) && (abs((ty + 2 * th) - ch) < abs(ty)))
+          ty += th;
+        else if (ty + th > ch)
+          {
+             int test_y = ty - th;
+
+             if ((test_y >= 0) || (ty + th - ch > abs(test_y)))
+               ty -= th;
+          }
+     }
+   else if ((ty > py) && (py > th))
+     {
+        if (ty + th < ch)
+          ty += th;
+     }
+   TTDBG("ADJUST (FLIP):  tx=%d,ty=%d\n", tx, ty);
+   if (inside_eventarea)
+     {
+        if ((tx == px) && ((tx + tw + tt->pad.x < cw) || (tx + tw > cw))) tx += tt->pad.x;
+        else if ((tx - tt->pad.x > 0) || (tx < 0)) tx -= tt->pad.x;
+        if ((ty == py) && ((ty + th + tt->pad.y < ch) || (ty + th > ch))) ty += tt->pad.y;
+        else if ((ty - tt->pad.y > 0) || (ty < 0)) ty -= tt->pad.y;
+     }
+   TTDBG("PAD:  tx=%d,ty=%d\n", tx, ty);
    if (tt->pad.bx * 2 + tw < cw)
      {
         if (tx < tt->pad.bx) tx = tt->pad.bx;
-        else if (tx + tw >= cw - tt->pad.bx) tx = cw - tw - tt->pad.bx;
+        else if ((tx >= tw) && (tx + tt->pad.bx <= cw)) tx += tt->pad.bx;
+        else if (tx - tt->pad.bx >= 0) tx -= tt->pad.bx;
      }
-
+   else if (tx < 0) tx -= tt->pad.bx;
+   else if (tx > cw) tx += tt->pad.bx;
    if (tt->pad.by * 2 + th < ch)
      {
         if (ty < tt->pad.by) ty = tt->pad.by;
-        else if (ty + th >= ch - tt->pad.by) ty = ch - th - tt->pad.by;
+        else if ((ty >= th) && (ty + tt->pad.by <= ch)) ty += tt->pad.by;
+        else if (ty - tt->pad.by >= 0) ty -= tt->pad.by;
      }
-
-   evas_object_move(tt->tooltip, tx, ty);
-   evas_object_resize(tt->tooltip, tw, th);
+   else if (ty < 0) ty -= tt->pad.by;
+   else if (ty > ch) ty += tt->pad.by;
+   TTDBG("PAD (BORDER):  tx=%d,ty=%d\n", tx, ty);
+   if (((tx < 0) && (tw < cw)) || ((ty < 0) && (th < ch)))
+     {
+        TTDBG("POSITIONING FAILED! THIS IS A BUG SOMEWHERE!\n");
+        abort();
+        return;
+     }
+   evas_object_move(tt->tt_win ? : tt->tooltip, tx, ty);
+   evas_object_resize(tt->tt_win ? : tt->tooltip, tw, th);
+   TTDBG("FINAL: tx=%d,ty=%d,tw=%d,th=%d\n", tx, ty, tw, th);
    evas_object_show(tt->tooltip);
 
    if (inside_eventarea)
@@ -404,15 +553,13 @@ _elm_tooltip_obj_mouse_in_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj _
 
    if ((tt->show_timer) || (tt->tooltip)) return;
 
-   tt->show_timer = ecore_timer_add
-     (_elm_config->tooltip_delay, _elm_tooltip_timer_show_cb, tt);
+   tt->show_timer = ecore_timer_add(_elm_config->tooltip_delay, _elm_tooltip_timer_show_cb, tt);
+   TTDBG("MOUSE IN\n");
 }
 
 static void
-_elm_tooltip_obj_mouse_out_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info  __UNUSED__)
+_elm_tooltip_obj_mouse_out_cb(Elm_Tooltip *tt, Evas *e  __UNUSED__, Evas_Object *obj __UNUSED__, Evas_Event_Mouse_Out *event __UNUSED__)
 {
-   Elm_Tooltip *tt = data;
-
    if (tt->visible_lock) return;
 
    if (!tt->tooltip)
@@ -420,11 +567,11 @@ _elm_tooltip_obj_mouse_out_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj
         _elm_tooltip_show_timer_stop(tt);
         return;
      }
-
    _elm_tooltip_hide_anim_start(tt);
+   TTDBG("MOUSE OUT\n");
 }
 
-static void _elm_tooltip_obj_del_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj, void *event_info  __UNUSED__);
+static void _elm_tooltip_obj_free_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj, void *event_info  __UNUSED__);
 
 static void
 _elm_tooltip_unset(Elm_Tooltip *tt)
@@ -440,16 +587,16 @@ _elm_tooltip_unset(Elm_Tooltip *tt)
            _elm_tooltip_obj_mouse_in_cb, tt);
         evas_object_event_callback_del_full
           (tt->eventarea, EVAS_CALLBACK_MOUSE_OUT,
-           _elm_tooltip_obj_mouse_out_cb, tt);
+           (Evas_Object_Event_Cb)_elm_tooltip_obj_mouse_out_cb, tt);
         evas_object_event_callback_del_full
-          (tt->eventarea, EVAS_CALLBACK_DEL, _elm_tooltip_obj_del_cb, tt);
+          (tt->eventarea, EVAS_CALLBACK_FREE, _elm_tooltip_obj_free_cb, tt);
 
         evas_object_data_del(tt->eventarea, _tooltip_key);
      }
    if (tt->owner)
      {
         evas_object_event_callback_del_full
-          (tt->owner, EVAS_CALLBACK_DEL, _elm_tooltip_obj_del_cb, tt);
+          (tt->owner, EVAS_CALLBACK_FREE, _elm_tooltip_obj_free_cb, tt);
         elm_widget_tooltip_del(tt->owner, tt);
      }
 
@@ -458,7 +605,7 @@ _elm_tooltip_unset(Elm_Tooltip *tt)
 }
 
 static void
-_elm_tooltip_obj_del_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj, void *event_info  __UNUSED__)
+_elm_tooltip_obj_free_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj, void *event_info  __UNUSED__)
 {
    Elm_Tooltip *tt = data;
    if (tt->eventarea == obj) tt->eventarea = NULL;
@@ -467,13 +614,25 @@ _elm_tooltip_obj_del_cb(void *data, Evas *e  __UNUSED__, Evas_Object *obj, void
 }
 
 static Evas_Object *
-_elm_tooltip_label_create(void *data, Evas_Object *obj)
+_elm_tooltip_label_create(void *data, Evas_Object *obj __UNUSED__, Evas_Object *tooltip)
 {
-   Evas_Object *label = elm_label_add(obj);
+   Evas_Object *label = elm_label_add(tooltip);
    if (!label)
      return NULL;
    elm_object_style_set(label, "tooltip");
-   elm_label_label_set(label, data);
+   elm_object_text_set(label, data);
+   return label;
+}
+
+static Evas_Object *
+_elm_tooltip_trans_label_create(void *data, Evas_Object *obj __UNUSED__, Evas_Object *tooltip)
+{
+   Evas_Object *label = elm_label_add(tooltip);
+   const char **text = data;
+   if (!label)
+     return NULL;
+   elm_object_style_set(label, "tooltip");
+   elm_object_domain_translatable_text_set(label, text[0], text[1]);
    return label;
 }
 
@@ -483,6 +642,15 @@ _elm_tooltip_label_del_cb(void *data, Evas_Object *obj __UNUSED__, void *event_i
    eina_stringshare_del(data);
 }
 
+static void
+_elm_tooltip_trans_label_del_cb(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+{
+   const char **text = data;
+   eina_stringshare_del(text[0]);
+   eina_stringshare_del(text[1]);
+   free(text);
+}
+
 static void
 _elm_tooltip_data_clean(Elm_Tooltip *tt)
 {
@@ -531,7 +699,7 @@ elm_tooltip_theme(Elm_Tooltip *tt)
  *        @a Evas_Object parameters will receive @a owner as value.
  * @param data what to provide to @a func as callback data/context.
  * @param del_cb called when data is not needed anymore, either when
- *        another callback replaces @func, the tooltip is unset with
+ *        another callback replaces @p func, the tooltip is unset with
  *        elm_object_tooltip_unset() or the owner object @a obj
  *        dies. This callback receives as the first parameter the
  *        given @a data, and @c event_info is NULL.
@@ -561,13 +729,13 @@ elm_object_sub_tooltip_content_cb_set(Evas_Object *eventarea, Evas_Object *owner
           {
              if (tt->owner != eventarea)
                evas_object_event_callback_del_full
-                 (tt->owner, EVAS_CALLBACK_DEL, _elm_tooltip_obj_del_cb, tt);
+                 (tt->owner, EVAS_CALLBACK_FREE, _elm_tooltip_obj_free_cb, tt);
 
              elm_widget_tooltip_del(tt->owner, tt);
 
              if (owner != eventarea)
                evas_object_event_callback_add
-                 (owner, EVAS_CALLBACK_DEL, _elm_tooltip_obj_del_cb, tt);
+                 (owner, EVAS_CALLBACK_FREE, _elm_tooltip_obj_free_cb, tt);
 
              elm_widget_tooltip_add(tt->owner, tt);
           }
@@ -590,18 +758,16 @@ elm_object_sub_tooltip_content_cb_set(Evas_Object *eventarea, Evas_Object *owner
 
         just_created = EINA_TRUE;
 
-        evas_object_event_callback_add
-          (eventarea, EVAS_CALLBACK_MOUSE_IN,
+        evas_object_event_callback_add(eventarea, EVAS_CALLBACK_MOUSE_IN,
            _elm_tooltip_obj_mouse_in_cb, tt);
-        evas_object_event_callback_add
-          (eventarea, EVAS_CALLBACK_MOUSE_OUT,
-           _elm_tooltip_obj_mouse_out_cb, tt);
-        evas_object_event_callback_add
-          (eventarea, EVAS_CALLBACK_DEL, _elm_tooltip_obj_del_cb, tt);
+        evas_object_event_callback_add(eventarea, EVAS_CALLBACK_MOUSE_OUT,
+           (Evas_Object_Event_Cb)_elm_tooltip_obj_mouse_out_cb, tt);
+        evas_object_event_callback_add(eventarea, EVAS_CALLBACK_FREE,
+           _elm_tooltip_obj_free_cb, tt);
 
         if (owner != eventarea)
           evas_object_event_callback_add
-            (owner, EVAS_CALLBACK_DEL, _elm_tooltip_obj_del_cb, tt);
+            (owner, EVAS_CALLBACK_FREE, _elm_tooltip_obj_free_cb, tt);
 
         elm_widget_tooltip_add(tt->owner, tt);
      }
@@ -677,6 +843,24 @@ elm_object_tooltip_text_set(Evas_Object *obj, const char *text)
      (obj, _elm_tooltip_label_create, text, _elm_tooltip_label_del_cb);
 }
 
+/**
+ */
+EAPI void
+elm_object_tooltip_domain_translatable_text_set(Evas_Object *obj, const char *domain, const char *text)
+{
+   const char **data;
+   EINA_SAFETY_ON_NULL_RETURN(obj);
+   EINA_SAFETY_ON_NULL_RETURN(text);
+
+   data = malloc(2 * sizeof(char *));
+   if (!data) return;
+   data[0] = eina_stringshare_add(domain);
+   data[1] = eina_stringshare_add(text);
+   elm_object_tooltip_content_cb_set
+     (obj, _elm_tooltip_trans_label_create, data,
+      _elm_tooltip_trans_label_del_cb);
+}
+
 /**
  * Set the content to be shown in the tooltip object
  *
@@ -690,7 +874,7 @@ elm_object_tooltip_text_set(Evas_Object *obj, const char *text)
  * @param func the function used to create the tooltip contents.
  * @param data what to provide to @a func as callback data/context.
  * @param del_cb called when data is not needed anymore, either when
- *        another callback replaces @func, the tooltip is unset with
+ *        another callback replaces @p func, the tooltip is unset with
  *        elm_object_tooltip_unset() or the owner object @a obj
  *        dies. This callback receives as the first parameter the
  *        given @a data, and @c event_info is NULL.
@@ -756,32 +940,33 @@ elm_object_tooltip_style_get(const Evas_Object *obj)
 }
 
 /**
- * Get the configured tooltip delay
+ * @brief Disable size restrictions on an object's tooltip
+ * @param obj The tooltip's anchor object
+ * @param disable If EINA_TRUE, size restrictions are disabled
+ * @return EINA_FALSE on failure, EINA_TRUE on success
  *
- * This gets the globally configured tooltip delay in seconds
- *
- * @return The tooltip delay
- * @ingroup Tooltips
+ * This function allows a tooltip to expand beyond its parent window's canvas.
+ * It will instead be limited only by the size of the display.
  */
-EAPI double
-elm_tooltip_delay_get(void)
+EAPI Eina_Bool
+elm_object_tooltip_window_mode_set(Evas_Object *obj, Eina_Bool disable)
 {
-   return _elm_config->tooltip_delay;
+   ELM_TOOLTIP_GET_OR_RETURN(tt, obj, EINA_FALSE);
+   return tt->free_size = disable;
 }
 
 /**
- * Set the configured tooltip delay
+ * @brief Retrieve size restriction state of an object's tooltip
+ * @param obj The tooltip's anchor object
+ * @return If EINA_TRUE, size restrictions are disabled
  *
- * This sets the globally configured delay to tooltip
- *
- * @param delay The delay to show the tooltip
- * @return EINA_TRUE if value is valid and setted
- * @ingroup Tooltips
+ * This function returns whether a tooltip is allowed to expand beyond
+ * its parent window's canvas.
+ * It will instead be limited only by the size of the display.
  */
 EAPI Eina_Bool
-elm_tooltip_delay_set(double delay)
+elm_object_tooltip_window_mode_get(const Evas_Object *obj)
 {
-   if (delay < 0.0) return EINA_FALSE;
-   _elm_config->tooltip_delay = delay;
-   return EINA_TRUE;
+   ELM_TOOLTIP_GET_OR_RETURN(tt, obj, EINA_FALSE);
+   return tt->free_size;
 }
